shpinfo package
===============

Submodules
----------

shpinfo.shpinfo module
----------------------

.. automodule:: shpinfo.shpinfo
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: shpinfo
    :members:
    :undoc-members:
    :show-inheritance:
